function varargout = guide_radiobutton(varargin)
% GUIDE_RADIOBUTTON M-file for guide_radiobutton.fig
%      GUIDE_RADIOBUTTON, by itself, creates a new GUIDE_RADIOBUTTON or raises the existing
%      singleton*.
%
%      H = GUIDE_RADIOBUTTON returns the handle to a new GUIDE_RADIOBUTTON or the handle to
%      the existing singleton*.
%
%      GUIDE_RADIOBUTTON('Property','Value',...) creates a new GUIDE_RADIOBUTTON using the
%      given property value pairs. Unrecognized properties are passed via
%      varargin to guide_radiobutton_OpeningFcn.  This calling syntax produces a
%      warning when there is an existing singleton*.
%
%      GUIDE_RADIOBUTTON('CALLBACK') and GUIDE_RADIOBUTTON('CALLBACK',hObject,...) call the
%      local function named CALLBACK in GUIDE_RADIOBUTTON.M with the given input
%      arguments.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help guide_radiobutton

% Last Modified by GUIDE v2.5 26-Jun-2002 19:56:01

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @guide_radiobutton_OpeningFcn, ...
                   'gui_OutputFcn',  @guide_radiobutton_OutputFcn, ...
                   'gui_LayoutFcn',  [], ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before guide_radiobutton is made visible.
function guide_radiobutton_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   unrecognized PropertyName/PropertyValue pairs from the
%            command line (see VARARGIN)

% Choose default command line output for guide_radiobutton
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes guide_radiobutton wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = guide_radiobutton_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

% --- Executes on button press in first_cb_tag.
function first_cb_tag_Callback(hObject, eventdata, handles)
% hObject    handle to first_cb_tag (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of first_cb_tag
turned_on = get(hObject,'value');
if turned_on
    set(handles.second_cb_tag, 'value', 0);
end

% --- Executes on button press in second_cb_tag.
function second_cb_tag_Callback(hObject, eventdata, handles)
% hObject    handle to second_cb_tag (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of second_cb_tag
turned_on = get(hObject,'value');
if turned_on
    set(handles.first_cb_tag, 'value', 0);
end